"use client";
import React, { useState } from "react";
import VisaOption from "./VisaOption";
import Link from "next/link";
import MultiStepForm from "./MultiStepForm/Form";

export const MultiStepsForm = ({
	step,
	setStep,
	purpose,
	setPurpose,
	selectedVisa,
	setSelectedVisa,
}: {
	step: number;
	setStep: (step: number) => void;
	purpose: string;
	setPurpose: (purpose: string) => void;
	selectedVisa: number;
	setSelectedVisa: (visa: number) => void;
}) => {
	const visaOptions = [
		{
			id: 1,
			title: "30 Days Single Entry",
			stayPeriod: "30 Days",
			validity: "58 Days",
			processingTime: "3 to 4 Business Days",
			price: "7,400",
			isExpress: false,
			isPopular: true,
		},
		{
			id: 2,
			title: "30 Days Single Entry",
			stayPeriod: "30 Days",
			validity: "58 Days",
			processingTime: "2 to 3 Business Days",
			price: "8,450",
			isExpress: false,
			isPopular: true,
		},
		{
			id: 3,
			title: "60 Days Single Entry",
			stayPeriod: "60 Days",
			validity: "58 Days",
			processingTime: "2 to 3 Business Days",
			price: "15,500",
			isExpress: false,
			isPopular: true,
		},
		{
			id: 4,
			title: "60 Days Multiple Entry",
			stayPeriod: "60 Days",
			validity: "58 Days",
			processingTime: "3 to 4 Business Days",
			price: "21,000",
			isExpress: false,
			isPopular: true,
		},
	];

	const steps = ["Purpose", "Visa Options", "Application Form"];

	return (
		<div className="w-full p-12 bg-white rounded-lg shadow-md">
			<h1 className="text-2xl font-bold text-center mb-6">
				France Visa Application
			</h1>
			<p className="text-center mb-8 text-gray-600">
				Ready for your next adventure?
			</p>

			<div className="flex px-48 justify-between items-center">
				{steps.map((currentStep, index) => (
					<React.Fragment key={currentStep}>
						<div className="flex flex-col items-center">
							<div
								className={`w-8 h-8 rounded-full flex items-center justify-center ${
									index + 1 <= step
										? "bg-emerald-600 text-white"
										: "bg-gray-200 text-gray-600"
								}`}
							>
								{index + 1}
							</div>
						</div>
						{index < steps.length - 1 && (
							<div
								className={`h-1 flex-1 ${
									index + 1 < step ? "bg-emerald-600" : "bg-gray-200"
								}`}
							/>
						)}
					</React.Fragment>
				))}
			</div>

			{step === 1 && (
				<>
					<p className="text-center text-gray-600 my-8">
						Select the Purpose of your visit
					</p>

					<div className="grid grid-cols-2 gap-4 my-8">
						<button
							className={`p-4 border rounded-lg flex h-full justify-center items-center gap-4 md:gap-12 ${
								purpose === "Tourist"
									? "border-emerald-500 bg-emerald-50/[0.5]"
									: "border-gray-300"
							}`}
							onClick={() => setPurpose("Tourist")}
						>
							<img
								src="./../tourist-icon.png"
								alt="Tourist"
								className="w-16 h-16 mb-2"
							/>
							<span className="text-base md:text-lg">Tourist</span>
						</button>

						<button
							className={`p-4 border rounded-lg flex h-full justify-center items-center gap-4 md:gap-12 ${
								purpose === "Job Seeker"
									? "border-emerald-500 bg-emerald-50/[0.5]"
									: "border-gray-300"
							}`}
							onClick={() => setPurpose("Job Seeker")}
						>
							<img
								src="./../job-seeker.png"
								alt="Job Seeker"
								className="w-16 h-16 mb-2"
							/>
							<span className="text-base md:text-lg">Job Seeker</span>
						</button>

						<button
							className={`p-4 border rounded-lg flex h-full items-center gap-4 md:gap-12 justify-center ${
								purpose === "F-1"
									? "border-emerald-500 bg-emerald-50/[0.5]"
									: "border-gray-300"
							}`}
							onClick={() => setPurpose("F-1")}
						>
							<img
								src="./../job-seeker.png"
								alt="Job Seeker"
								className="w-16 h-16 mb-2"
							/>
							<span className="text-base md:text-lg">F-1 Visa</span>
						</button>

						<button
							className={`p-4 border rounded-lg flex h-full items-center justify-center gap-4 md:gap-12 ${
								purpose === "F-2"
									? "border-emerald-500 bg-emerald-50/[0.5]"
									: "border-gray-300"
							}`}
							onClick={() => setPurpose("F-2")}
						>
							<img
								src="./../job-seeker.png"
								alt="Job Seeker"
								className="w-16 h-16 mb-2"
							/>
							<span className="text-base md:text-lg">F-2 Visa</span>
						</button>
					</div>

					{/* <p className="text-sm text-blue-700 mt-6 bg-blue-50 p-6 rounded-xl">
						<span className="mr-2">💡</span>
						PassportMe has brought joy to over 100,000 happy travellers!
					</p> */}
				</>
			)}

			{step === 2 && (
				<>
					<h2 className="text-center text-gray-600 my-8">
						Which Visa do you wish to apply?
					</h2>

					<div className="grid grid-cols-2 gap-4">
						{visaOptions.map((option, index) => (
							<VisaOption
								key={option.id}
								{...option}
								onSelect={setSelectedVisa}
								selected={selectedVisa === option.id}
							/>
						))}
					</div>
				</>
			)}

			{step === 3 && (
				<div className="space-y-6 pt-12 flex flex-col w-full items-center">
					<a
						className="underline text-lg lg:text-xl px-12 py-3 text-emerald-700"
						href="/france-passportme.pdf"
						target="_blank"
						rel="noopener noreferrer"
					>
						Your application is ready!
					</a>
				</div>
			)}

			{/* Other steps... */}
		</div>
	);
};
